/**
 * Copyright 2019-2023 Britanicus <marcusbritanicus@gmail.com>
 *
 * This file is a part of DesQ Shell (https://gitlab.com/DesQ/Shell)
 * DesQ Shell is the main Shell UI of the DesQ Project
 *
 * This file was originally taken from LXQt project
 * <https://github.com/lxqt/lxqt-panel>
 * Several modifications have been made to suit the needs of DesQ
 * Any and all bug reports are to be filed with DesQ and not LXQt.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * at your option, any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 **/

#include "Task.hpp"

#include <wayqt/ToplevelManager.hpp>

TaskButton::TaskButton( QWidget *parent ) : QToolButton( parent ) {
    /** No borders when not under mouse */
    setAutoRaise( true );

    /** A fairly large icon */
    setIconSize( QSize( 24, 24 ) );

    /** Button with focus will be checked */
    setCheckable( true );
    setChecked( false );

    connect(
        this, &QToolButton::clicked, [ = ] () {
            if ( mToplevel->isActive() ) {
                if ( mToplevel->isMinimized() ) {
                    mToplevel->restore();
                }

                else {
                    mToplevel->minimize();
                }

                setChecked( false );
            }

            else {
                mToplevel->focus();
                setChecked( true );
            }
        }
    );
}


TaskButton::~TaskButton() {
}


void TaskButton::addTask( WQt::Toplevel *tl ) {
    mToplevel = tl;
}
